/* Copyright (C) 2000-2020 by Massimiliano Ghilardi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 */
#include "test.h"

int main() {
  test_stl_chars();
  test_stl_fmt();
  test_stl_utf8();
  test_stl_vector();
  return 0;
}
